@@ -169,12 +169,13 @@ run_test("parsable-R",
 )
 
 # failure
-run_test("parsable-R", suffix = "-fail.R", std_err = "not parsable")
+run_test("parsable-R", suffix = "-fail.R", std_out = "Full context", std_err = "1 1")
 
 run_test(
   "parsable-R",
   suffix = "-fail.Rmd",
-  std_err = "parsable-R-fail.Rmd is not parsable"
+  std_out = "parsable-R-fail.Rmd",
+  std_err = "1 1"
 )
 
 ### . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . ..
